"use strict";
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveAndRunNgcc = void 0;
const child_process_1 = require("child_process");
const path_1 = require("path");
const resolver_1 = require("../common/resolver");
const version_provider_1 = require("./version_provider");
/**
 * Resolve ngcc from the directory that contains the specified `tsconfig` and
 * run ngcc.
 */
async function resolveAndRunNgcc(tsconfig, progress) {
    var _a, _b;
    const directory = (0, path_1.dirname)(tsconfig);
    const ngcc = await (0, version_provider_1.resolveNgcc)(directory);
    if (!ngcc) {
        throw new Error(`Failed to resolve ngcc from ${directory}`);
    }
    const index = ngcc.resolvedPath.lastIndexOf('node_modules');
    // By default, ngcc assumes the node_modules directory that it needs to process
    // is in the cwd. In our case, we should set cwd to the directory where ngcc
    // is resolved to, not the directory where tsconfig.json is located. See
    // https://github.com/angular/angular/blob/e23fd1f38205410e0ecb601ec73847cea2dea2a8/packages/compiler-cli/ngcc/src/command_line_options.ts#L18-L24
    const cwd = index > 0 ? ngcc.resolvedPath.slice(0, index) : process.cwd();
    const args = [
        '--tsconfig',
        tsconfig,
    ];
    if (ngcc.version.greaterThanOrEqual(new resolver_1.Version('11.2.4'))) {
        // See https://github.com/angular/angular/commit/241784bde8582bcbc00b8a95acdeb3b0d38fbec6
        args.push('--typings-only');
    }
    const childProcess = (0, child_process_1.fork)(ngcc.resolvedPath, args, {
        cwd: (0, path_1.resolve)(cwd),
        silent: true,
        execArgv: [], // do not inherit flags like --inspect from parent process
    });
    let stderr = '';
    (_a = childProcess.stderr) === null || _a === void 0 ? void 0 : _a.on('data', (data) => {
        stderr += data.toString();
    });
    (_b = childProcess.stdout) === null || _b === void 0 ? void 0 : _b.on('data', (data) => {
        for (let entry of data.toString().split('\n')) {
            entry = entry.trim();
            if (entry) {
                progress.report(entry);
            }
        }
    });
    return new Promise((resolve, reject) => {
        childProcess.on('error', (error) => {
            reject(error);
        });
        childProcess.on('close', (code) => {
            if (code === 0) {
                resolve();
            }
            else {
                reject(new Error(`ngcc for ${tsconfig} returned exit code ${code}, stderr: ${stderr.trim()}`));
            }
        });
    });
}
exports.resolveAndRunNgcc = resolveAndRunNgcc;
//# sourceMappingURL=ngcc.js.map