/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import * as ts from 'typescript/lib/tsserverlibrary';
import * as lsp from 'vscode-languageserver';
import * as pugLs from 'pugjs-language-service';
import * as vscode from 'vscode-languageserver-types';
import { TextDocument } from 'vscode-languageserver-textdocument';
export { translateHtmlOffsetToPug, translateHtmlPositionToPug, translateHtmlRangeToPug, translatePosition, translatePugOffsetToHtml, translatePugPositionToHtml, translateRange, } from './translation';
export declare const isDebugMode: boolean;
/**
 * Extract the file path from the specified `uri`.
 * @param uri
 */
export declare function uriToFilePath(uri: string): string;
/**
 * Converts the specified `filePath` to a proper URI.
 * @param filePath
 */
export declare function filePathToUri(filePath: string): lsp.DocumentUri;
/**
 * Get the starting offset/position from a source map result
 * @param sourceMapPosition
 */
export declare function extractOffsetFromSourceMapPosition<T = vscode.Position | number>(sourceMapPosition: [{
    start: T;
    end: T;
}, {
    isEmptyTagCompletion: boolean;
} | undefined] | undefined): T | undefined;
/**
 * Get the parsed PugDocument that corresponds to a ts.server.ScriptInfo
 * @param pugLs
 * @param scriptInfo
 * @param scriptInfo
 */
export declare function getPugDocumentFromScriptInfo(pugLs: pugLs.LanguageService, scriptInfo: ts.server.ScriptInfo): pugLs.PugDocument;
/**
 * Check if a project is configured
 * @param project
 */
export declare function isConfiguredProject(project: ts.server.Project): project is ts.server.ConfiguredProject;
/**
 * A class that tracks items in most recently used order.
 */
export declare class MruTracker {
    private readonly set;
    update(item: string): void;
    delete(item: string): void;
    /**
     * Returns all items sorted by most recently used.
     */
    getAll(): string[];
}
/**
 * Combine ts.SymboleDisplayParts into a regular string
 * @param parts
 */
export declare function tsDisplayPartsToText(parts: ts.SymbolDisplayPart[]): string;
/**
 *
 * This function attempts to use *internal* TypeScript APIs to find the original source spans for
 * the `ts.DefinitionInfo` using source maps. If it fails, this function returns the same
 * `ts.DefinitionInfo` that was passed in.
 *
 * @see https://github.com/angular/vscode-ng-language-service/issues/1588
 */
export declare function getMappedDefinitionInfo(info: ts.DefinitionInfo, project: ts.server.Project): ts.DefinitionInfo;
/**
 * Convert lsp.Position to the absolute offset in the file. LSP keeps track of
 * offset using 0-based index whereas TypeScript uses 1-based index.
 * @param file Used to determine the offsets.
 * @param position
 */
export declare function lspPositionToTsPosition(file: ts.server.ScriptInfo | TextDocument, position: lsp.Position): number;
/**
 * Convert ts.TextSpan to lsp.TextSpan. TypeScript keeps track of offset using
 * 1-based index whereas LSP uses 0-based index.
 * @param file Used to determine the offsets.
 * @param textSpan
 */
export declare function tsTextSpanToLspRange(file: ts.server.ScriptInfo | TextDocument, textSpan: ts.TextSpan): lsp.Range;
/**
 * Convert lsp.Range which is made up of `start` and `end` positions to
 * TypeScript's absolute offsets.
 * @param file Used to determine the offsets.
 * @param range
 */
export declare function lspRangeToTsPositions(file: TextDocument, range: lsp.Range): [number, number];
/**
 * Convert a ts.DiagnosticRelatedInformation array to a
 * lsp.DiagnosticRelatedInformation array
 * @param file Used to determine the offsets.
 * @param relatedInfo
 */
export declare function tsRelatedInformationToLspRelatedInformation(file: ts.server.ScriptInfo | TextDocument, relatedInfo?: ts.DiagnosticRelatedInformation[]): lsp.DiagnosticRelatedInformation[] | undefined;
